from wombopy.core import generate


__app_name__ = "wombopy"
__version__ = "0.1.2"

(
    SUCCESS,
    DIR_ERROR,
    FILE_ERROR,
    DB_READ_ERROR,
    DB_WRITE_ERROR,
    JSON_ERROR,
    ID_ERROR,
) = range(7)

ERRORS = {
    DIR_ERROR: "config directory error",
    FILE_ERROR: "config file error",
    ID_ERROR: "to-do id error",
}


from typing import Optional

import typer

from wombopy import __app_name__, __version__, generate
from wombopy.core import identify

app = typer.Typer()


def _version_callback(value: bool) -> None:
    if value:
        typer.echo(f"{__app_name__} v{__version__}")
        raise typer.Exit()


@app.command(help="Create an image from wombo.art")
def run(open_result: Optional[bool] = typer.Option(
    None,
    "--show",
    "-s",
    help="Show back the image"
),
        identify_key: str = typer.Argument(...),
        prompt: str = typer.Argument(...),
        style: int = typer.Argument(...)
) -> None:
    typer.secho(f"Prompt: {prompt}\tStyle: {style}")
    typer.secho("Starting...")

    res = identify(identify_key=identify_key)
    generate(res['id_token'], prompt, style, open_result)

    return


@app.callback()
def main(
        version: Optional[bool] = typer.Option(
            None,
            "--version",
            "-v",
            help="Show the application's version and exit.",
            callback=_version_callback,
            is_eager=True,
        )
) -> None:
    return



from setuptools import setup

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name='wombopy',
    version='0.1.2',
    description='A module to generate wombo.art images',
    author='Holy Tanuki',
    long_description=long_description,
    long_description_content_type="text/markdown",
    packages=['wombopy'],
    install_requires=[
        "typer==0.4.0",
        "colorama==0.4.4",
        "shellingham==1.4.0",
        "pytest==7.0.1",
        "requests==2.27.1",
    ],
    python_requires=">=3.9",
)
